#[repr(C)]pub struct CDriverMsg {
pub extension: [wchar_t; 12],
pub file_id: FILE_ID_INFO,
pub mem_sized_used: c_ulonglong,
pub entropy: f64,
pub pid: c_ulong,
pub irp_op: c_uchar,
pub is_entropy_calc: u8,
pub file_change: c_uchar,
pub file_location_info: c_uchar,
pub filepath: UnicodeString,
pub gid: c_ulonglong,
pub next: *const CDriverMsg,
}Expand description
The C object returned by the minifilter, available through ReplyIrp.
It is low level and use C pointers logic which is not always compatible with RUST (in particular
the lifetime of *next). That’s why we convert it asap to a plain Rust IOMessage object.
next is null (0x0) when there is no IOMessage remaining.
Fields
extension: [wchar_t; 12]file_id: FILE_ID_INFOmem_sized_used: c_ulonglongentropy: f64pid: c_ulongirp_op: c_ucharis_entropy_calc: u8file_change: c_ucharfile_location_info: c_ucharfilepath: UnicodeStringgid: c_ulonglongnext: *const CDriverMsgnull (0x0) when there is no IOMessage remaining