#[repr(C)]pub struct UnicodeString {
pub length: c_ushort,
pub maximum_length: c_ushort,
pub buffer: *const wchar_t,
}Expand description
This class is the straight Rust translation of the Win32 API
UNICODE_STRING,
returned by the driver.
Fields
length: c_ushortmaximum_length: c_ushortbuffer: *const wchar_tImplementations
Sourceimpl UnicodeString
impl UnicodeString
Sourcepub fn to_string_ext(&self, extension: [wchar_t; 12]) -> String
pub fn to_string_ext(&self, extension: [wchar_t; 12]) -> String
Get the file path from the UnicodeString path and the extension returned by the driver.